@@ -11,8 +11,13 @@ fn main() {
                 break 'outer;
             }
             let actor_preset = actor_presets_iter.next().unwrap();
-            let mut actor = game.add_actor(format!("{:?}", actor_preset), actor_preset);
+            let actor_string = format!("{:?}", actor_preset);
+            let mut actor = game.add_actor(&actor_string, actor_preset);
             actor.translation = Vec2::new(x as f32, (-y) as f32);
+
+            let mut text_actor = game.add_text_actor(&actor_string, &actor_string);
+            text_actor.translation = Vec2::new(x as f32, (-y - 70) as f32);
+            text_actor.font_size = 22.0;
         }
     }
 
