@@ -122,6 +122,7 @@ impl Game {
     /// any variables.
     ///
     /// ```no_run
+    /// # use rusty_engine::prelude::*;
     /// let mut game = Game::new();
     /// game.run(|game_state| {
     ///     println!("This game has been running for: {:.2}", game_state.seconds_since_startup);
@@ -131,6 +132,7 @@ impl Game {
     /// If you don't want to do anything, you can use the closure `|_| {}`
     ///
     /// ```no_run
+    /// # use rusty_engine::prelude::*;
     /// let mut game = Game::new();
     /// game.run(|_| {});
     /// ```
@@ -169,6 +171,7 @@ impl Game {
 pub struct GameState {
     // Empty collections for users
     pub bool_map: HashMap<String, bool>,
+    pub f32_map: HashMap<String, f32>,
     pub i32_map: HashMap<String, i32>,
     pub u8_map: HashMap<String, u8>,
     pub u32_map: HashMap<String, u32>,
@@ -176,6 +179,7 @@ pub struct GameState {
     pub string_map: HashMap<String, String>,
     pub timer_map: HashMap<String, Timer>,
     pub bool_vec: Vec<bool>,
+    pub f32_vec: Vec<f32>,
     pub i32_vec: Vec<i32>,
     pub u8_vec: Vec<u8>,
     pub u32_vec: Vec<u32>,
@@ -256,7 +260,7 @@ fn setup(
 }
 
 // system - the magic that connects Rusty Engine to Bevy, frame by frame
-#[allow(clippy::type_complexity)]
+#[allow(clippy::type_complexity, clippy::too_many_arguments)]
 fn game_logic_sync(
     mut commands: Commands,
     asset_server: Res<AssetServer>,
